==> python-gitlab_2.10.1.orig.tar.gz: python-gitlab-2.10.1/gitlab/v4/objects/__init__.py <==
# -*- coding: utf-8 -*-
#
# Copyright (C) 2013-2017 Gauvain Pocentek <gauvain@pocentek.net>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from .access_requests import *
from .appearance import *
from .applications import *
from .audit_events import *
from .award_emojis import *
from .badges import *
from .boards import *
from .branches import *
from .broadcast_messages import *
from .clusters import *
from .commits import *
from .container_registry import *
from .custom_attributes import *
from .deploy_keys import *
from .deploy_tokens import *
from .deployments import *
from .discussions import *
from .environments import *
from .epics import *
from .events import *
from .export_import import *
from .features import *
from .files import *
from .geo_nodes import *
from .groups import *
from .hooks import *
from .issues import *
from .jobs import *
from .keys import *
from .labels import *
from .ldap import *
from .members import *
from .merge_request_approvals import *
from .merge_requests import *
from .milestones import *
from .namespaces import *
from .notes import *
from .notification_settings import *
from .packages import *
from .pages import *
from .personal_access_tokens import *
from .pipelines import *
from .projects import *
from .push_rules import *
from .releases import *
from .runners import *
from .services import *
from .settings import *
from .sidekiq import *
from .snippets import *
from .statistics import *
from .tags import *
from .templates import *
from .todos import *
from .triggers import *
from .users import *
from .variables import *
from .wikis import *

# TODO: deprecate these in favor of gitlab.const.*
VISIBILITY_PRIVATE = "private"
VISIBILITY_INTERNAL = "internal"
VISIBILITY_PUBLIC = "public"

ACCESS_GUEST = 10
ACCESS_REPORTER = 20
ACCESS_DEVELOPER = 30
ACCESS_MASTER = 40
ACCESS_OWNER = 50

__all__ = [name for name in dir() if not name.startswith("_")]

==> python-gitlab-3.1.0.tar.gz: python-gitlab-3.1.0/gitlab/v4/objects/__init__.py <==
# -*- coding: utf-8 -*-
#
# Copyright (C) 2013-2017 Gauvain Pocentek <gauvain@pocentek.net>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from .access_requests import *
from .appearance import *
from .applications import *
from .audit_events import *
from .award_emojis import *
from .badges import *
from .boards import *
from .branches import *
from .broadcast_messages import *
from .clusters import *
from .commits import *
from .container_registry import *
from .custom_attributes import *
from .deploy_keys import *
from .deploy_tokens import *
from .deployments import *
from .discussions import *
from .environments import *
from .epics import *
from .events import *
from .export_import import *
from .features import *
from .files import *
from .geo_nodes import *
from .groups import *
from .hooks import *
from .issues import *
from .jobs import *
from .keys import *
from .labels import *
from .ldap import *
from .members import *
from .merge_request_approvals import *
from .merge_requests import *
from .merge_trains import *
from .milestones import *
from .namespaces import *
from .notes import *
from .notification_settings import *
from .packages import *
from .pages import *
from .personal_access_tokens import *
from .pipelines import *
from .projects import *
from .push_rules import *
from .releases import *
from .runners import *
from .services import *
from .settings import *
from .sidekiq import *
from .snippets import *
from .statistics import *
from .tags import *
from .templates import *
from .todos import *
from .topics import *
from .triggers import *
from .users import *
from .variables import *
from .wikis import *

__all__ = [name for name in dir() if not name.startswith("_")]
